pub fn fill_random(buf: &mut [u8]) -> Result<(), AlkaliError>Expand description
Fill buf with random data suitable for cryptographic use.
Returns an error if Sodium could not be correctly initialised.
pub fn fill_random(buf: &mut [u8]) -> Result<(), AlkaliError>Fill buf with random data suitable for cryptographic use.
Returns an error if Sodium could not be correctly initialised.